bayespy.inference.vmp.nodes.gamma.GammaDistribution.compute_logpdf
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.compute_logpdf